[savara-commits] savara SVN: r623 - in branches/experimental/2.0.x/bundles/org.savara.activity: src/main/java/org/savara/activity/model and 1 other directory.

do-not-reply at jboss.org do-not-reply at jboss.org
Wed Jan 26 12:28:01 EST 2011


Author: objectiser
Date: 2011-01-26 12:28:01 -0500 (Wed, 26 Jan 2011)
New Revision: 623

Added:
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Context.java
Removed:
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Conversation.java
Modified:
   branches/experimental/2.0.x/bundles/org.savara.activity/schema/Activity.xsd
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Activity.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Analysis.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Error.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Facet.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/InstanceFinished.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/InstanceStarted.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Interaction.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Lifecycle.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/MessageReceived.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/MessageSent.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/ObjectFactory.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Process.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/ProtocolAnalysis.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Task.java
   branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/package-info.java
Log:
Changed Conversation to be Context, as conversation is not usually something known in advance by the endpoints, but probably will be derived based on correlation of message exchanges based on contextual information.

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/schema/Activity.xsd
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/schema/Activity.xsd	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/schema/Activity.xsd	2011-01-26 17:28:01 UTC (rev 623)
@@ -16,10 +16,11 @@
 
     <complexType name="Facet" abstract="true"></complexType>
 
-    <complexType name="Conversation">
+    <complexType name="Context">
     	<complexContent>
     		<extension base="tns:Facet">
-     			<attribute name="conversationInstanceId" type="string"></attribute>
+    			<attribute name="name" type="string"></attribute>
+    			<attribute name="value" type="string"></attribute>
     		</extension>
     	</complexContent>
     </complexType>
@@ -28,9 +29,9 @@
     	<complexContent>
     		<extension base="tns:Facet">
     			<!--  May be the same as the 'componentInstanceId' -->
-     			<attribute name="processInstanceId" type="string"></attribute>
-     			<attribute name="processDefinitionId" type="string"></attribute>
-     			<attribute name="processName" type="string"></attribute>
+     			<attribute name="instanceId" type="string"></attribute>
+     			<attribute name="definitionId" type="string"></attribute>
+     			<attribute name="name" type="string"></attribute>
     		</extension>
     	</complexContent>
     </complexType>
@@ -38,8 +39,8 @@
     <complexType name="Task">
     	<complexContent>
     		<extension base="tns:Facet">
-     			<attribute name="taskDefinitionId" type="string"></attribute>
-     			<attribute name="taskName" type="string"></attribute>
+     			<attribute name="definitionId" type="string"></attribute>
+     			<attribute name="name" type="string"></attribute>
     		</extension>
     	</complexContent>
     </complexType>

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Activity.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Activity.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Activity.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Analysis.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Analysis.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Analysis.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Added: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Context.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Context.java	                        (rev 0)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Context.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -0,0 +1,94 @@
+//
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
+// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
+// Any modifications to this file will be lost upon recompilation of the source schema. 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
+//
+
+
+package org.savara.activity.model;
+
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlAttribute;
+import javax.xml.bind.annotation.XmlType;
+
+
+/**
+ * <p>Java class for Context complex type.
+ * 
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ * 
+ * <pre>
+ * &lt;complexType name="Context">
+ *   &lt;complexContent>
+ *     &lt;extension base="{http://www.savara.org/activity}Facet">
+ *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *       &lt;attribute name="value" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *     &lt;/extension>
+ *   &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ * 
+ * 
+ */
+ at XmlAccessorType(XmlAccessType.FIELD)
+ at XmlType(name = "Context")
+public class Context
+    extends Facet
+{
+
+    @XmlAttribute(name = "name")
+    protected String name;
+    @XmlAttribute(name = "value")
+    protected String value;
+
+    /**
+     * Gets the value of the name property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getName() {
+        return name;
+    }
+
+    /**
+     * Sets the value of the name property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setName(String value) {
+        this.name = value;
+    }
+
+    /**
+     * Gets the value of the value property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getValue() {
+        return value;
+    }
+
+    /**
+     * Sets the value of the value property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setValue(String value) {
+        this.value = value;
+    }
+
+}

Deleted: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Conversation.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Conversation.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Conversation.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -1,67 +0,0 @@
-//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
-// Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
-//
-
-
-package org.savara.activity.model;
-
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlType;
-
-
-/**
- * <p>Java class for Conversation complex type.
- * 
- * <p>The following schema fragment specifies the expected content contained within this class.
- * 
- * <pre>
- * &lt;complexType name="Conversation">
- *   &lt;complexContent>
- *     &lt;extension base="{http://www.savara.org/activity}Facet">
- *       &lt;attribute name="conversationInstanceId" type="{http://www.w3.org/2001/XMLSchema}string" />
- *     &lt;/extension>
- *   &lt;/complexContent>
- * &lt;/complexType>
- * </pre>
- * 
- * 
- */
- at XmlAccessorType(XmlAccessType.FIELD)
- at XmlType(name = "Conversation")
-public class Conversation
-    extends Facet
-{
-
-    @XmlAttribute(name = "conversationInstanceId")
-    protected String conversationInstanceId;
-
-    /**
-     * Gets the value of the conversationInstanceId property.
-     * 
-     * @return
-     *     possible object is
-     *     {@link String }
-     *     
-     */
-    public String getConversationInstanceId() {
-        return conversationInstanceId;
-    }
-
-    /**
-     * Sets the value of the conversationInstanceId property.
-     * 
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *     
-     */
-    public void setConversationInstanceId(String value) {
-        this.conversationInstanceId = value;
-    }
-
-}

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Error.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Error.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Error.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Facet.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Facet.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Facet.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 
@@ -33,8 +33,8 @@
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "Facet")
 @XmlSeeAlso({
-    Conversation.class,
     Error.class,
+    Context.class,
     Process.class,
     Task.class,
     Interaction.class,

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/InstanceFinished.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/InstanceFinished.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/InstanceFinished.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/InstanceStarted.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/InstanceStarted.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/InstanceStarted.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Interaction.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Interaction.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Interaction.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Lifecycle.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Lifecycle.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Lifecycle.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/MessageReceived.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/MessageReceived.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/MessageReceived.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/MessageSent.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/MessageSent.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/MessageSent.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/ObjectFactory.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/ObjectFactory.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/ObjectFactory.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 
@@ -37,22 +37,14 @@
     }
 
     /**
-     * Create an instance of {@link Conversation }
+     * Create an instance of {@link Process }
      * 
      */
-    public Conversation createConversation() {
-        return new Conversation();
+    public Process createProcess() {
+        return new Process();
     }
 
     /**
-     * Create an instance of {@link Task }
-     * 
-     */
-    public Task createTask() {
-        return new Task();
-    }
-
-    /**
      * Create an instance of {@link Activity }
      * 
      */
@@ -61,11 +53,11 @@
     }
 
     /**
-     * Create an instance of {@link MessageReceived }
+     * Create an instance of {@link Context }
      * 
      */
-    public MessageReceived createMessageReceived() {
-        return new MessageReceived();
+    public Context createContext() {
+        return new Context();
     }
 
     /**
@@ -77,6 +69,14 @@
     }
 
     /**
+     * Create an instance of {@link MessageReceived }
+     * 
+     */
+    public MessageReceived createMessageReceived() {
+        return new MessageReceived();
+    }
+
+    /**
      * Create an instance of {@link Error }
      * 
      */
@@ -85,19 +85,19 @@
     }
 
     /**
-     * Create an instance of {@link InstanceFinished }
+     * Create an instance of {@link Task }
      * 
      */
-    public InstanceFinished createInstanceFinished() {
-        return new InstanceFinished();
+    public Task createTask() {
+        return new Task();
     }
 
     /**
-     * Create an instance of {@link Process }
+     * Create an instance of {@link InstanceFinished }
      * 
      */
-    public Process createProcess() {
-        return new Process();
+    public InstanceFinished createInstanceFinished() {
+        return new InstanceFinished();
     }
 
     /**

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Process.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/ProtocolAnalysis.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/ProtocolAnalysis.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Task.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/package-info.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/package-info.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 @javax.xml.bind.annotation.XmlSchema(namespace = "http://www.savara.org/activity", elementFormDefault = javax.xml.bind.annotation.XmlNsForm.QUALIFIED)



More information about the savara-commits mailing list
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Process.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Process.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 
@@ -23,9 +23,9 @@
  * &lt;complexType name="Process">
  *   &lt;complexContent>
  *     &lt;extension base="{http://www.savara.org/activity}Facet">
- *       &lt;attribute name="processInstanceId" type="{http://www.w3.org/2001/XMLSchema}string" />
- *       &lt;attribute name="processDefinitionId" type="{http://www.w3.org/2001/XMLSchema}string" />
- *       &lt;attribute name="processName" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *       &lt;attribute name="instanceId" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *       &lt;attribute name="definitionId" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
  *     &lt;/extension>
  *   &lt;/complexContent>
  * &lt;/complexType>
@@ -39,83 +39,83 @@
     extends Facet
 {
 
-    @XmlAttribute(name = "processInstanceId")
-    protected String processInstanceId;
-    @XmlAttribute(name = "processDefinitionId")
-    protected String processDefinitionId;
-    @XmlAttribute(name = "processName")
-    protected String processName;
+    @XmlAttribute(name = "instanceId")
+    protected String instanceId;
+    @XmlAttribute(name = "definitionId")
+    protected String definitionId;
+    @XmlAttribute(name = "name")
+    protected String name;
 
     /**
      * Gets the value of the processInstanceId property.
      * 
      * @return
      *     possible object is
      *     {@link String }
      *     
      */
-    public String getProcessInstanceId() {
-        return processInstanceId;
+    public String getInstanceId() {
+        return instanceId;
     }
 
     /**
      * Sets the value of the processInstanceId property.
      * 
      * @param value
      *     allowed object is
      *     {@link String }
      *     
      */
-    public void setProcessInstanceId(String value) {
-        this.processInstanceId = value;
+    public void setInstanceId(String value) {
+        this.instanceId = value;
     }
 
     /**
      * Gets the value of the processDefinitionId property.
      * 
      * @return
      *     possible object is
      *     {@link String }
      *     
      */
-    public String getProcessDefinitionId() {
-        return processDefinitionId;
+    public String getDefinitionId() {
+        return definitionId;
     }
 
     /**
      * Sets the value of the processDefinitionId property.
      * 
      * @param value
      *     allowed object is
      *     {@link String }
      *     
      */
-    public void setProcessDefinitionId(String value) {
-        this.processDefinitionId = value;
+    public void setDefinitionId(String value) {
+        this.definitionId = value;
     }
 
     /**
-     * Gets the value of the processName property.
+     * Gets the value of the name property.
      * 
      * @return
      *     possible object is
      *     {@link String }
      *     
      */
-    public String getProcessName() {
-        return processName;
+    public String getName() {
+        return name;
     }
 
     /**
-     * Sets the value of the processName property.
+     * Sets the value of the name property.
      * 
      * @param value
      *     allowed object is
      *     {@link String }
      *     
      */
-    public void setProcessName(String value) {
-        this.processName = value;
+    public void setName(String value) {
+        this.name = value;
     }
 
 }
@@ -39,83 +39,83 @@
 
     /**
-     * Gets the value of the processInstanceId property.
+     * Gets the value of the instanceId property.
      * 
      * @return
@@ -39,83 +39,83 @@
 
     /**
-     * Sets the value of the processInstanceId property.
+     * Sets the value of the instanceId property.
      * 
      * @param value
@@ -39,83 +39,83 @@
 
     /**
-     * Gets the value of the processDefinitionId property.
+     * Gets the value of the definitionId property.
      * 
      * @return
@@ -39,83 +39,83 @@
 
     /**
-     * Sets the value of the processDefinitionId property.
+     * Sets the value of the definitionId property.
      * 
      * @param value

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/ProtocolAnalysis.java
===================================================================
--- branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Task.java	2011-01-26 00:04:53 UTC (rev 622)
+++ branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/Task.java	2011-01-26 17:28:01 UTC (rev 623)
@@ -2,7 +2,7 @@
 // This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vhudson-jaxb-ri-2.2-146 
 // See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
 // Any modifications to this file will be lost upon recompilation of the source schema. 
-// Generated on: 2011.01.25 at 04:37:56 PM GMT 
+// Generated on: 2011.01.26 at 04:49:35 PM GMT 
 //
 
 
@@ -23,8 +23,8 @@
  * &lt;complexType name="Task">
  *   &lt;complexContent>
  *     &lt;extension base="{http://www.savara.org/activity}Facet">
- *       &lt;attribute name="taskDefinitionId" type="{http://www.w3.org/2001/XMLSchema}string" />
- *       &lt;attribute name="taskName" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *       &lt;attribute name="definitionId" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
  *     &lt;/extension>
  *   &lt;/complexContent>
  * &lt;/complexType>
@@ -38,57 +38,57 @@
     extends Facet
 {
 
-    @XmlAttribute(name = "taskDefinitionId")
-    protected String taskDefinitionId;
-    @XmlAttribute(name = "taskName")
-    protected String taskName;
+    @XmlAttribute(name = "definitionId")
+    protected String definitionId;
+    @XmlAttribute(name = "name")
+    protected String name;
 
     /**
      * Gets the value of the taskDefinitionId property.
      * 
      * @return
      *     possible object is
      *     {@link String }
      *     
      */
-    public String getTaskDefinitionId() {
-        return taskDefinitionId;
+    public String getDefinitionId() {
+        return definitionId;
     }
 
     /**
      * Sets the value of the taskDefinitionId property.
      * 
      * @param value
      *     allowed object is
      *     {@link String }
      *     
      */
-    public void setTaskDefinitionId(String value) {
-        this.taskDefinitionId = value;
+    public void setDefinitionId(String value) {
+        this.definitionId = value;
     }
 
     /**
-     * Gets the value of the taskName property.
+     * Gets the value of the name property.
      * 
      * @return
      *     possible object is
      *     {@link String }
      *     
      */
-    public String getTaskName() {
-        return taskName;
+    public String getName() {
+        return name;
     }
 
     /**
-     * Sets the value of the taskName property.
+     * Sets the value of the name property.
      * 
      * @param value
      *     allowed object is
      *     {@link String }
      *     
      */
-    public void setTaskName(String value) {
-        this.taskName = value;
+    public void setName(String value) {
+        this.name = value;
     }
 
 }
@@ -38,57 +38,57 @@
 
     /**
-     * Gets the value of the taskDefinitionId property.
+     * Gets the value of the definitionId property.
      * 
      * @return
@@ -38,57 +38,57 @@
 
     /**
-     * Sets the value of the taskDefinitionId property.
+     * Sets the value of the definitionId property.
      * 
      * @param value

Modified: branches/experimental/2.0.x/bundles/org.savara.activity/src/main/java/org/savara/activity/model/package-info.java
===================================================================